document.addEventListener('DOMContentLoaded', () => {
    // 预处理所有菜品和标签的拼音数据
    const generatePinyinData = () => {
    document.querySelectorAll('.menu-item').forEach(item => {
        try {
            const dishElement = item.querySelector('span');
            const dishName = dishElement.textContent;

            // 生成菜品名称的拼音全拼（不带声调）
            const pinyinFull = pinyinPro.pinyin(dishName, {
                toneType: 'none',
                type: 'string',
                v: true
            }).replace(/\s+/g, '');

            // 生成菜品名称的拼音首字母
            const pinyinInitials = pinyinPro.pinyin(dishName, {
                pattern: 'first',
                toneType: 'none',
                type: 'string'
            }).replace(/\s+/g, '');

            // 提取标签
            const labels = Array.from(item.querySelectorAll('.text-label'))
                .map(label => label.textContent.trim());

            // 为每个标签生成拼音全拼和首字母
            const labelPinyinFull = labels.map(label => 
                pinyinPro.pinyin(label, {
                    toneType: 'none',
                    type: 'string',
                    v: true
                }).replace(/\s+/g, '').toLowerCase()
            );
            const labelPinyinInitials = labels.map(label => 
                pinyinPro.pinyin(label, {
                    pattern: 'first',
                    toneType: 'none',
                    type: 'string'
                }).replace(/\s+/g, '').toLowerCase()
            );

            // 存储到 DOM 元素的 dataset 属性中
            item.dataset.pinyinFull = pinyinFull.toLowerCase();
            item.dataset.pinyinInitials = pinyinInitials.toLowerCase();
            item.dataset.labels = labels.join(' ').toLowerCase(); // 中文标签
            item.dataset.labelPinyinFull = labelPinyinFull.join(' '); // 标签拼音全拼
            item.dataset.labelPinyinInitials = labelPinyinInitials.join(' '); // 标签拼音首字母
        } catch (error) {
            console.error('生成拼音或标签数据失败:', error);
        }
    });
};

    // 增强搜索功能
    const enhancedSearch = (searchTerm) => {
    tabPanes.forEach(pane => {
        let hasVisibleItems = false;
        pane.querySelectorAll('.menu-item').forEach(item => {
            const dishName = item.querySelector('span').textContent.toLowerCase();
            const pinyinFull = item.dataset.pinyinFull || '';
            const pinyinInitials = item.dataset.pinyinInitials || '';
            const labels = item.dataset.labels || '';
            const labelPinyinFull = item.dataset.labelPinyinFull || '';
            const labelPinyinInitials = item.dataset.labelPinyinInitials || '';

            // 检查搜索词是否匹配菜品名称、拼音或标签（中文、拼音全拼、首字母）
            const match = dishName.includes(searchTerm) || 
                          pinyinFull.includes(searchTerm) || 
                          pinyinInitials.includes(searchTerm) ||
                          labels.includes(searchTerm) ||
                          labelPinyinFull.includes(searchTerm) ||
                          labelPinyinInitials.includes(searchTerm);

            item.style.display = match ? "flex" : "none";
            if (match) hasVisibleItems = true;
        });
        // 自动隐藏没有匹配结果的分类
        pane.style.display = hasVisibleItems ? "block" : "none";
    });
};

    // DOM元素引用
    const menuPage = document.getElementById('menuPage');
    const confirmPage = document.getElementById('confirmPage');
    const nextBtn = document.getElementById('nextBtn');
    const confirmBtn = document.getElementById('confirmBtn');
    const selectedItemsList = document.getElementById('selectedItems');
    const selectedCount = document.getElementById('selectedCount');
    const mealDateInput = document.getElementById('mealDate');
    const mealTimeSelect = document.getElementById('mealTime');
    const confirmCodeInput = document.getElementById('confirmCode');
    const errorMsg = document.getElementById('errorMsg');
    const searchInput = document.getElementById('searchInput');
    const tabNav = document.querySelector('.tab-nav');
    const tabPanes = document.querySelectorAll('.tab-pane');
    const noCookingTodayCheckbox = document.getElementById('noCookingToday');
    const normalConfirm = document.getElementById('normalConfirm');
    const noCookingConfirm = document.getElementById('noCookingConfirm');
    let lastActiveTab = document.querySelector('.tab-pane.active').id;
    let isNoCookingToday = false;

    // 初始化拼音数据
    generatePinyinData();

const setDefaultMealTime = () => {
    const now = new Date();
    const currentHour = now.getHours();
    
    // 获取本地日期字符串的工具函数
    const formatLocalDate = (date) => {
        const y = date.getFullYear();
        const m = String(date.getMonth() + 1).padStart(2, '0');
        const d = String(date.getDate()).padStart(2, '0');
        return `${y}-${m}-${d}`;
    };

    let mealDate = formatLocalDate(now);
    let mealTime = '午餐'; // 默认值
    
    if (currentHour >= 18) { 
        // 18:00-23:59，第二天午餐
        const tomorrow = new Date(now);
        tomorrow.setDate(now.getDate() + 1);
        mealDate = formatLocalDate(tomorrow);
    } else if (currentHour >= 11) { 
        // 11:00-17:59，当天晚餐
        mealTime = '晚餐';
    } 
    // 0:00-10:59 保持默认值（当天午餐）

    // 应用设置
    mealDateInput.value = mealDate;
    mealTimeSelect.value = mealTime;
};

    // 下一步按钮点击事件
    nextBtn.addEventListener('click', () => {
        isNoCookingToday = noCookingTodayCheckbox.checked;
        const selectedCheckboxes = Array.from(document.querySelectorAll('input[type="checkbox"]:checked'));

        if (isNoCookingToday) {
            menuPage.style.display = 'none';
            confirmPage.style.display = 'block';
            normalConfirm.style.display = 'none';
            noCookingConfirm.style.display = 'block';
        } else {
            if (selectedCheckboxes.length === 0) {
                alert('请至少选择一道菜！');
                return;
            }
            menuPage.style.display = 'none';
            confirmPage.style.display = 'block';
            normalConfirm.style.display = 'block';
            noCookingConfirm.style.display = 'none';
            selectedItemsList.innerHTML = '';
            selectedCheckboxes.forEach((checkbox, index) => {
                const li = document.createElement('li');
                li.textContent = `${index + 1}. ${checkbox.value}`;
                selectedItemsList.appendChild(li);
            });
            selectedCount.textContent = `您已选择${selectedCheckboxes.length}道菜品`;
            setDefaultMealTime();
        }
    });

    // 确认下单按钮点击事件
    confirmBtn.addEventListener('click', async () => {
        const confirmCode = confirmCodeInput.value.trim();
        let orderData = {
            confirmCode: confirmCode,
            isNoCookingToday: isNoCookingToday
        };

        if (isNoCookingToday) {
            const selectedActivities = Array.from(document.querySelectorAll('input[name="activity"]:checked')).map(cb => cb.value);
            orderData.activities = selectedActivities;
            orderData.note = document.getElementById('noCookingNote').value.trim();
        } else {
            const selectedCheckboxes = Array.from(document.querySelectorAll('input[type="checkbox"]:checked'));
            if (selectedCheckboxes.length === 0) {
                alert('请至少选择一道菜！');
                return;
            }
            orderData.selectedItems = selectedCheckboxes.map(cb => cb.value);
            orderData.mealDate = mealDateInput.value;
            orderData.mealTime = mealTimeSelect.value;
            orderData.note = document.getElementById('note').value.trim();
        }

        if (!confirmCode) {
            errorMsg.textContent = '请输入确认码';
            errorMsg.style.display = 'block';
            return;
        }

        try {
            const response = await fetch('/submit-order', {
                method: 'POST',
                headers: { 'Content-Type': 'application/json' },
                body: JSON.stringify(orderData)
            });
            
            const result = await response.json();
            
            if (response.ok) {
                alert(isNoCookingToday ? 
                    '下单成功！那老婆你今天要吃点好的！已发送邮件通知。' : 
                    '下单成功！已发送邮件通知。');
                window.location.reload();
            } else {
                errorMsg.textContent = result.error || '下单失败，请检查确认码';
                errorMsg.style.display = 'block';
            }
        } catch (error) {
            console.error('请求失败:', error);
            errorMsg.textContent = '网络错误，请重试';
            errorMsg.style.display = 'block';
        }
    });

    // 搜索功能
    searchInput.addEventListener('focus', () => {
        if (noCookingTodayCheckbox.parentElement.style.display === 'none') {
            noCookingTodayCheckbox.parentElement.style.display = 'flex';
        }
    });

    searchInput.addEventListener('input', function(e) {
        const searchTerm = e.target.value.toLowerCase().trim();
        
        if (searchTerm) {
            tabNav.style.display = "none";
            tabPanes.forEach(pane => pane.style.display = "block");
            enhancedSearch(searchTerm);
        } else {
            tabNav.style.display = "flex";
            tabPanes.forEach(pane => {
                pane.style.display = pane.id === lastActiveTab ? "block" : "none";
                pane.querySelectorAll('.menu-item').forEach(item => {
                    item.style.display = "flex";
                });
            });
        }
    });

    // 分类切换
    document.querySelectorAll('.tab-btn').forEach(button => {
        button.addEventListener('click', () => {
            searchInput.value = '';
            tabNav.style.display = 'flex';
            tabPanes.forEach(pane => {
                pane.classList.remove('active');
                pane.style.display = 'none';
                pane.querySelectorAll('.menu-item').forEach(item => {
                    item.style.display = 'flex';
                });
            });
            document.querySelectorAll('.tab-btn').forEach(btn => btn.classList.remove('active'));
            button.classList.add('active');
            lastActiveTab = button.getAttribute('data-tab');
            const activePane = document.getElementById(lastActiveTab);
            activePane.classList.add('active');
            activePane.style.display = 'block';
        });
    });
});

// 主题切换功能
const themes = {
    default: {
        primary: '#1E90FF',
        secondary: '#87CEEB',
        background: 'linear-gradient(135deg, #E6F0FA, #4DA8DA)',
        text: '#333',
        buttonBg: 'linear-gradient(135deg, #1E90FF, #87CEEB)',
        thumb: '#1E90FF',
        border: '#A3CFFA',
        inputBg: '#F0F8FF',
        itemBg: '#E6F0FA',
        itemBgAlt: '#F0F8FF'
    },
    orange: {
        primary: '#FFA500',
        secondary: '#FFB347',
        background: 'linear-gradient(135deg, #FFF5E1, #FFA500)',
        text: '#333',
        buttonBg: 'linear-gradient(135deg, #FFA500, #FFB347)',
        thumb: '#FFA500',
        border: '#FFA500',
        inputBg: '#FFF5E1',
        itemBg: '#FFF5E1',
        itemBgAlt: '#FFFBF2'
    },
    magenta: {
        primary: '#FF00FF',
        secondary: '#FF77FF',
        background: 'linear-gradient(135deg, #FFE1FF, #FF00FF)',
        text: '#333',
        buttonBg: 'linear-gradient(135deg, #FF00FF, #FF77FF)',
        thumb: '#FF00FF',
        border: '#FF00FF',
        inputBg: '#FFE1FF',
        itemBg: '#FFE1FF',
        itemBgAlt: '#FFF1FF'
    }
};

// 修改主题切换函数，增加输入元素样式刷新
function changeTheme(themeName) {
    const root = document.documentElement;
    const t = themes[themeName];
    
    // 更新CSS变量
    root.style.setProperty('--primary-color', t.primary);
    root.style.setProperty('--secondary-color', t.secondary);
    root.style.setProperty('--background', t.background);
    root.style.setProperty('--text-color', t.text);
    root.style.setProperty('--button-bg', t.buttonBg);
    root.style.setProperty('--thumb-color', t.thumb);
    root.style.setProperty('--border-color', t.border);
    root.style.setProperty('--input-bg', t.inputBg);
    root.style.setProperty('--item-bg', t.itemBg);
    root.style.setProperty('--item-bg-alt', t.itemBgAlt);

    // 强制重绘输入元素
    document.querySelectorAll('input, select, textarea').forEach(el => {
        el.style.transform = 'translateZ(0)';
    });
}

function togglePalette() {
    const palette = document.getElementById('themePalette');
    palette.style.display = palette.style.display === 'block' ? 'none' : 'block';
}